@@ -1,7 +1,7 @@
 /*
  * nzb
  *
- * Copyright (C) 2004-2005 Mattias Nordstrom <matta at ftlight net>
+ * Copyright (C) 2004-2006 Mattias Nordstrom <matta at ftlight net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,7 +61,7 @@ void Decoder::stop()
 void Decoder::processFiles()
 {
 	if (getNext(&file, &seg)) {
-		emit decodeEvent("Decoding ["+QString::number(file)+": "+QString::number(seg+1)+"/"+QString::number(nzblist->getFile(file)->getSegments()->size())+"] "+nzblist->getFile(file)->getSegment(seg)->getMsgid(), thread_id);
+		emit decodeEvent("Decoding ["+QString::number(file+1)+": "+QString::number(seg+1)+"/"+QString::number(nzblist->getFile(file)->getSegments()->size())+"] "+nzblist->getFile(file)->getSegment(seg)->getMsgid(), thread_id);
 		
 		processing = true;
 		//QTimer::singleShot(0, this, SLOT(processFile()));
@@ -94,7 +94,7 @@ void Decoder::processFile()
 	
 	processing = false;
 	//emit decodeEvent("Idle", thread_id, 1);
-	emit decodeEvent("Decoded ["+QString::number(file)+": "+QString::number(seg+1)+"/"+QString::number(nzblist->getFile(file)->getSegments()->size())+"] "+nzblist->getFile(file)->getSegment(seg)->getMsgid(), thread_id, 1);
+	emit decodeEvent("Decoded ["+QString::number(file+1)+": "+QString::number(seg+1)+"/"+QString::number(nzblist->getFile(file)->getSegments()->size())+"] "+nzblist->getFile(file)->getSegment(seg)->getMsgid(), thread_id, 1);
 }
 
 bool Decoder::getNext(int *file, int *seg)
@@ -314,7 +314,7 @@ void Decoder::yDecode(int file, int seg)
 
 bool Decoder::crc32Check(int crc32, QString c_crc)
 {
-	unsigned long crc;
+	unsigned int crc;
 	QString calc_crc;
 	
 	crc = crc32 ^ 0xFFFFFFFFl;
