@@ -1,7 +1,7 @@
 /*
  * nzb
  *
- * Copyright (C) 2004-2005 Mattias Nordstrom <matta at ftlight net>
+ * Copyright (C) 2004-2006 Mattias Nordstrom <matta at ftlight net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@ Downloader::Downloader(NzbList *nzblist, int thread_id, QMutex *file_lock, QTabl
 	this->thread_id = thread_id;
 	this->file_lock = file_lock;
 	this->l = l;
+	this->use_ssl = false;
 	connect(this, SIGNAL(downloadEvent(QString, int, int)), parent, SLOT(downloadEvent(QString, int, int)));
 }
 
@@ -56,11 +57,23 @@ void Downloader::init()
 	downloading = false;
 	connect(this, SIGNAL(processNext()), this, SLOT(processFiles()));
 	
+	use_ssl = ((MainWindow*)parent)->getConfig()->value("server/ssl").toBool();
+	
 	emit downloadEvent("Connecting", thread_id);
+	((MainWindow*)parent)->getDownloaderItem(thread_id)->setIcon(QIcon(":/images/connect_creating.png"));
 	usenet = new QTcpSocket();
-	connect(usenet, SIGNAL(readyRead()), this, SLOT(gotData()));
+	connect(usenet, SIGNAL(connected()), this, SLOT(gotConnected()));
+	
+	if (use_ssl) {
+		connect(&ssl, SIGNAL(readyRead()), this, SLOT(gotData()));
+		connect(usenet, SIGNAL(readyRead()), this, SLOT(ssl_readyRead()));
+		connect(&ssl, SIGNAL(outgoingSSLDataReady()), this, SLOT(ssl_outgoingReady()));
+	} else {
+		connect(usenet, SIGNAL(readyRead()), this, SLOT(gotData()));
+	}
+	
 	initialize(((MainWindow*)parent)->getConfig()->value("server/host").toString(), ((MainWindow*)parent)->getConfig()->value("server/port").toInt());
-
+	
 	last_time = QTime::currentTime();
 	last_bytes = 0;
 	total_bytes = 0;
@@ -76,7 +89,7 @@ void Downloader::processFiles()
 	
 	if (getNext()) {
 			downloading = true;
-			emit downloadEvent("Downloading ["+QString::number(file)+": "+QString::number(seg+1)+"/"+QString::number(nzblist->getFile(file)->getSegments()->size())+"] "+nzblist->getFile(file)->getSegment(seg)->getMsgid(), thread_id);
+			emit downloadEvent("Downloading ["+QString::number(file+1)+": "+QString::number(seg+1)+"/"+QString::number(nzblist->getFile(file)->getSegments()->size())+"] "+nzblist->getFile(file)->getSegment(seg)->getMsgid(), thread_id);
 			getArticle(nzblist->getFile(file)->getSegment(seg)->getMsgid());
 	}
 }
@@ -139,34 +152,95 @@ void Downloader::initialize(QString host, int port)
 	usenet->connectToHost(host, port);
 }
 
+void Downloader::gotConnected()
+{
+	if (use_ssl) {
+		if (!ssl.begin()) {
+			((MainWindow*)parent)->getDownloaderItem(thread_id)->setIcon(QIcon(":/images/connect_no.png"));
+			usenet->close();
+			emit downloadEvent("SSL connection failed", thread_id);
+			dldata.clear();
+		} else {
+			((MainWindow*)parent)->getDownloaderItem(thread_id)->setIcon(QIcon(":/images/encrypted.png"));
+		}
+	} else {
+		((MainWindow*)parent)->getDownloaderItem(thread_id)->setIcon(QIcon(":/images/connect_established.png"));
+	}
+}
+
 void Downloader::terminate()
 {
-	usenet->write(((QString)("QUIT\r\n")).toAscii());
-	usenet->close();
+	if (use_ssl) {
+		ssl.send(((QString)("QUIT\r\n")).toAscii());
+		usenet->close();
+	} else {
+		usenet->write(((QString)("QUIT\r\n")).toAscii());
+		usenet->close();
+	}
+	
+	((MainWindow*)parent)->getDownloaderItem(thread_id)->setIcon(QIcon(":/images/connect_no.png"));
 }
 
 void Downloader::getArticle(QString msgid)
 {
-	usenet->write(("ARTICLE "+msgid+"\r\n").toAscii());
-	usenet->flush();
+	if (use_ssl) {
+		ssl.send(("ARTICLE "+msgid+"\r\n").toAscii());
+	} else {
+		usenet->write(("ARTICLE "+msgid+"\r\n").toAscii());
+		usenet->flush();
+	}
+	
 	dldata.clear();
 }
 
+void Downloader::ssl_readyRead()
+{
+	/*QByteArray buf;
+	int size = usenet->bytesAvailable();
+	buf.resize(size);
+	usenet->readBlock(buf.data(), size);*/
+	ssl.putIncomingSSLData(usenet->readAll());
+}
+
+void Downloader::ssl_outgoingReady()
+{
+	usenet->write(ssl.getOutgoingSSLData());
+}
+
 void Downloader::gotData()
 {
-	if (!usenet->bytesAvailable()) return;
+	QIODevice *buffer;
+	QBuffer ssl_buf;
 
-	total_bytes += usenet->bytesAvailable();
+	if (use_ssl) {
+		ssl_buf.open(QBuffer::ReadWrite);
+		ssl_buf.write(ssl.recv());
+		ssl_buf.seek(0);
+		buffer = &ssl_buf;
+	} else {
+		buffer = usenet;
+	}
+	
+	if (!buffer->bytesAvailable()) {
+		qDebug("gotData() empty.");
+		return;
+	}
+
+	total_bytes += buffer->bytesAvailable();
 	
 	QByteArray hdata;
 	int pos;
 	
 	if (dldata.isEmpty()) {
-		hdata = usenet->readLine();
+		hdata = buffer->readLine();
 		if (hdata.left(3) == "200" || hdata.left(3) == "201") {
 			if (((MainWindow*)parent)->getConfig()->value("server/auth").toBool()) {
-				usenet->write(("AUTHINFO USER "+((MainWindow*)parent)->getConfig()->value("server/username").toString()+"\r\n").toAscii());
-				usenet->flush();
+				if (use_ssl) {
+					ssl.send(("AUTHINFO USER "+((MainWindow*)parent)->getConfig()->value("server/username").toString()+"\r\n").toAscii());
+				} else {
+					buffer->write(("AUTHINFO USER "+((MainWindow*)parent)->getConfig()->value("server/username").toString()+"\r\n").toAscii());
+					((QTcpSocket*)buffer)->flush();
+				}
 				return;
 			} else {
 				emit downloadEvent("Connected", thread_id, 3);
@@ -174,8 +248,12 @@ void Downloader::gotData()
 				return;
 			}
 		} else if (hdata.left(3) == "381") {
-			usenet->write(("AUTHINFO PASS "+((MainWindow*)parent)->getConfig()->value("server/password").toString()+"\r\n").toAscii());
-			usenet->flush();
+			if (use_ssl) {
+				ssl.send(("AUTHINFO PASS "+((MainWindow*)parent)->getConfig()->value("server/password").toString()+"\r\n").toAscii());
+			} else {
+				buffer->write(("AUTHINFO PASS "+((MainWindow*)parent)->getConfig()->value("server/password").toString()+"\r\n").toAscii());
+				((QTcpSocket*)buffer)->flush();
+			}
 			return;
 		} else if (hdata.left(3) == "281") {
 			qDebug("Connected");
@@ -188,19 +266,19 @@ void Downloader::gotData()
 			return;
 		} else if (hdata.left(2) == "22") {
 			dldata = hdata;
-			dldata += usenet->readAll();
+			dldata += buffer->readAll();
 		} else {
 			/*emit downloadEvent("Connect failure", thread_id);
 			qDebug("Connection failed.");
 			nzblist->getFile(file)->getSegment(seg)->setStatus(NZB_DOWNLOADED);
-			usenet->close();
+			buffer->close();
 			qDebug("NNTP Protocol handshake error.");
 			qDebug() << "Data: " << hdata;
 			return;*/
-			dldata = hdata+usenet->readAll();
+			dldata = hdata+buffer->readAll();
 		}
 	} else {
-		dldata += usenet->readAll();
+		dldata += buffer->readAll();
 	}
 	
 	if (dldata.right(5) == "\r\n.\r\n") {
@@ -230,9 +308,11 @@ void Downloader::gotData()
 
 void Downloader::speedMonitor()
 {
-	double speed = ((total_bytes - last_bytes) / last_time.secsTo(QTime::currentTime())) / 1000;
-	last_time = QTime::currentTime();
-	last_bytes = total_bytes;
+	if (int secs = last_time.secsTo(QTime::currentTime())) {
+		double speed = ((total_bytes - last_bytes) / secs) / 1000;
+		last_time = QTime::currentTime();
+		last_bytes = total_bytes;
 	
-	emit downloadEvent(QString::number(speed), thread_id, 4);
+		emit downloadEvent(QString::number(speed), thread_id, 4);
+	}
 }
