@@ -1,7 +1,7 @@
 /*
  * nzb
  *
- * Copyright (C) 2004-2005 Mattias Nordstrom <matta at ftlight net>
+ * Copyright (C) 2004-2006 Mattias Nordstrom <matta at ftlight net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 #include <QtNetwork>
 
 #include "nzbdata.h"
+#include "sslfilter.h"
 
 class Downloader : public QThread
 {
@@ -52,6 +53,9 @@ private slots:
 	void init();
 	void gotData();
 	void speedMonitor();
+	void gotConnected();
+	void ssl_readyRead();
+	void ssl_outgoingReady();
 
 private:
 	void initialize(QString host, int port);
@@ -71,6 +75,8 @@ private:
 	QTime last_time;
 	int total_bytes;
 	int last_bytes;
+	SSLFilter ssl;
+	bool use_ssl;
 };
 
 #endif
