@@ -1,7 +1,7 @@
 /*
  * nzb
  *
- * Copyright (C) 2004-2005 Mattias Nordstrom <matta at ftlight net>
+ * Copyright (C) 2004-2006 Mattias Nordstrom <matta at ftlight net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@ MainWindow::MainWindow()
 	l->setSelectionMode(QAbstractItemView::NoSelection);
 	l->setSelectionBehavior(QAbstractItemView::SelectRows);
 	l->setShowGrid(false);
+	l->verticalHeader()->hide();
 	
 	d = new QTableWidget(split);
 	
@@ -51,6 +52,7 @@ MainWindow::MainWindow()
 	d->setSelectionMode(QAbstractItemView::NoSelection);
 	d->setSelectionBehavior(QAbstractItemView::SelectRows);
 	d->setShowGrid(false);
+	d->verticalHeader()->hide();
 	
 	setCentralWidget(split);
 
@@ -66,13 +68,14 @@ MainWindow::MainWindow()
 	int i;
 	for (i=0; i<config->value("server/connections").toInt(); i++) {
 		downloaders.append(new Downloader(&nzblist, i, &file_lock, l, this));
-		d->setItem(i, 0, new QTableWidgetItem("Downloader #"+QString::number(i+1)));
+		d->setItem(i, 0, new QTableWidgetItem(QIcon(":/images/connect_no.png"), "Downloader #"+QString::number(i+1)));
 		d->setItem(i, 2, new QTableWidgetItem("0 kB/s"));
+		d->item(i, 2)->setTextAlignment(Qt::AlignRight);
 		connect(this, SIGNAL(fullStop()), downloaders[i], SLOT(stop()));
 	}
 
 	decoders.append(new Decoder(&nzblist, i, &file_lock, this));
-	d->setItem(i, 0, new QTableWidgetItem("Decoder #1"));
+	d->setItem(i, 0, new QTableWidgetItem(QIcon(":/images/decoder.png"), "Decoder #1"));
 	connect(this, SIGNAL(processDecoder()), decoders[0], SLOT(processFiles()));
 	connect(this, SIGNAL(fullStop()), decoders[0], SLOT(stop()));
 	
@@ -140,19 +143,19 @@ void MainWindow::createActions()
 	optionsAct->setStatusTip(tr("Show the options dialog"));
 	connect(optionsAct, SIGNAL(triggered()), this, SLOT(options()));
 	
-	startAct = new QAction(tr("&Start"), this);
+	startAct = new QAction(QIcon(":/images/start.png"), tr("&Start"), this);
 	startAct->setShortcut(tr("Ctrl+S"));
 	startAct->setStatusTip(tr("Start downloader"));
 	startAct->setEnabled(false);
 	connect(startAct, SIGNAL(triggered()), this, SLOT(start()));
 	
-	stopAct = new QAction(tr("S&top"), this);
+	stopAct = new QAction(QIcon(":/images/stop.png"), tr("S&top"), this);
 	stopAct->setShortcut(tr("Ctrl+T"));
 	stopAct->setStatusTip(tr("Stop downloader"));
 	stopAct->setEnabled(false);
 	connect(stopAct, SIGNAL(triggered()), this, SLOT(stop()));
 	
-	streamAct = new QAction(tr("St&ream"), this);
+	streamAct = new QAction(QIcon(":/images/stream.png"), tr("St&ream"), this);
 	streamAct->setShortcut(tr("Ctrl+R"));
 	streamAct->setStatusTip(tr("Start streaming"));
 	streamAct->setEnabled(false);
@@ -194,6 +197,11 @@ void MainWindow::createToolBars()
 {
 	fileToolBar = addToolBar(tr("File"));
 	fileToolBar->addAction(openAct);
+	
+	actionToolBar = addToolBar(tr("Actions"));
+	actionToolBar->addAction(startAct);
+	actionToolBar->addAction(stopAct);
+	actionToolBar->addAction(streamAct);
 }
 
 void MainWindow::createStatusBar()
@@ -213,7 +221,12 @@ void MainWindow::createStatusBar()
 
 void MainWindow::readSettings()
 {
-	config = new QSettings("nzb", "nzb");
+	if (QFile::exists("nzb.ini")) {
+		config = new QSettings("nzb.ini", QSettings::IniFormat);
+	} else {
+		config = new QSettings("nzb", "nzb");
+	}
+	
 	QPoint pos = config->value("mainwindow/pos", QPoint(200, 200)).toPoint();
 	QSize size = config->value("mainwindow/size", QSize(400, 400)).toSize();
 	resize(size);
@@ -285,6 +298,19 @@ void MainWindow::populateList()
 		l->setItem(row, 1, newItem_prog);
 		l->setItem(row, 2, newItem_tot);
 		l->setItem(row, 3, newItem_size);
+		
+		newItem_prog->setTextAlignment(Qt::AlignRight);
+		newItem_tot->setTextAlignment(Qt::AlignRight);
+		newItem_size->setTextAlignment(Qt::AlignRight);
+		
+		if (config->value("list/par_uncheck").toBool()) {
+			QRegExp rx("*vol*.par2");
+			rx.setPatternSyntax(QRegExp::Wildcard);
+			rx.setCaseSensitivity(Qt::CaseInsensitive);
+			if (nzblist.getFile(i)->getSubject().contains(rx)) {
+				newItem->setCheckState(Qt::Unchecked);
+			}
+		}
 
 		l->resizeRowToContents(row);
 
@@ -478,9 +504,19 @@ OptionsDlg::OptionsDlg(QWidget *parent) : QDialog(parent)
 	connect(ui.mediaBrowse, SIGNAL(clicked()), this, SLOT(browseMedia()));
 	
 	connect(ui.subfolders, SIGNAL(stateChanged(int)), this, SLOT(enableGuess(int)));
+	connect(ui.ssl, SIGNAL(stateChanged(int)), this, SLOT(sslChange(int)));
+	connect(ui.use_file, SIGNAL(clicked()), this, SLOT(useFile()));
 	
 	QSettings *config = ((MainWindow*)parent)->getConfig();
 	
+	if (QFile::exists("nzb.ini")) {
+		ui.use_file->setEnabled(false);
+	}
+	
+	#ifndef Q_WS_WIN
+	ui.use_file->setEnabled(false);
+	#endif
+	
 	ui.host->setText(config->value("server/host").toString());
 	ui.port->setText(config->value("server/port").toString());
 	ui.username->setText(config->value("server/username").toString());
@@ -493,6 +529,12 @@ OptionsDlg::OptionsDlg(QWidget *parent) : QDialog(parent)
 		ui.auth->setCheckState(Qt::Unchecked);
 	}
 
+	if (config->value("server/ssl").toBool()) {
+		ui.ssl->setCheckState(Qt::Checked);
+	} else {
+		ui.ssl->setCheckState(Qt::Unchecked);
+	}
+	
 	
 	if (config->value("list/autosort").toBool()) {
 		ui.autosort->setCheckState(Qt::Checked);
@@ -506,6 +548,12 @@ OptionsDlg::OptionsDlg(QWidget *parent) : QDialog(parent)
 		ui.hidecompleted->setCheckState(Qt::Unchecked);
 	}
 	
+	if (config->value("list/par_uncheck").toBool()) {
+		ui.par_uncheck->setCheckState(Qt::Checked);
+	} else {
+		ui.par_uncheck->setCheckState(Qt::Unchecked);
+	}
+	
 	ui.savepath->setText(config->value("output/savepath").toString());
 	if (config->value("output/subfolders").toBool()) {
 		ui.subfolders->setCheckState(Qt::Checked);
@@ -537,9 +585,11 @@ void OptionsDlg::accept()
 	config->setValue("server/password", ui.password->text());
 	config->setValue("server/connections", ui.connections->value());
 	config->setValue("server/auth", ((ui.auth->checkState() == Qt::Checked) ? true : false));
+	config->setValue("server/ssl", ((ui.ssl->checkState() == Qt::Checked) ? true : false));
 	
 	config->setValue("list/autosort", ((ui.autosort->checkState() == Qt::Checked) ? true : false));
 	config->setValue("list/hidecompleted", ((ui.hidecompleted->checkState() == Qt::Checked) ? true : false));
+	config->setValue("list/par_uncheck", ((ui.par_uncheck->checkState() == Qt::Checked) ? true : false));
 	
 	config->setValue("output/savepath", ui.savepath->text());
 	config->setValue("output/subfolders", ((ui.subfolders->checkState() == Qt::Checked) ? true : false));
@@ -585,3 +635,20 @@ void OptionsDlg::enableGuess(int state)
 		ui.guessalbum->setEnabled(false);
 	}	
 }
+
+void OptionsDlg::sslChange(int state)
+{
+	if (state == Qt::Checked) {
+		ui.port->setText("563");
+	} else {
+		ui.port->setText("119");
+	}	
+}
+
+void OptionsDlg::useFile()
+{
+	QSettings *config = new QSettings("nzb.ini", QSettings::IniFormat);
+	((MainWindow*)parent)->setConfig(config);
+	config->sync();
+	ui.use_file->setEnabled(false);
+}
