@@ -1,7 +1,7 @@
 /*
  * nzb
  *
- * Copyright (C) 2004-2005 Mattias Nordstrom <matta at ftlight net>
+ * Copyright (C) 2004-2006 Mattias Nordstrom <matta at ftlight net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 #include <QtGui>
 #include <QtXml>
 
-#define NZB_VERSION		"0.1.4"
+#define NZB_VERSION		"0.1.7"
 
 #define NZB_UNDEF		0
 
@@ -126,7 +126,7 @@ public:
 	NzbSeg* getSegment(int seg) { return &(segments[seg]); }
 	QString getNzbFileName() const { return nzbFileName; }
 	void setNzbFileName(QString nzbFile) { this->nzbFileName = nzbFile; }
-	static bool subjectLessThan(const NzbFile &nf1, const NzbFile &nf2) { return (nf1.subject < nf2.subject); }
+	static bool subjectLessThan(const NzbFile &nf1, const NzbFile &nf2);
 	int getBytes() const { return bytes; }
 	int getEncoding() const { return encoding; }
 	void setEncoding(int encoding) { this->encoding = encoding; }
