@@ -1,7 +1,7 @@
 /*
  * nzb
  *
- * Copyright (C) 2004-2005 Mattias Nordstrom <matta at ftlight net>
+ * Copyright (C) 2004-2006 Mattias Nordstrom <matta at ftlight net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -94,6 +94,11 @@ bool Output::getNext(int *file, int *seg)
 	file_lock->lock();
 	
 	for (;;) {
+		if (nzblist->getFile(*file)->getSegment(*seg)->getStatus() == NZB_NONE || nzblist->getFile(*file)->getSegment(*seg)->getStatus() == NZB_DOWNLOADING || nzblist->getFile(*file)->getSegment(*seg)->getStatus() == NZB_DOWNLOADED || nzblist->getFile(*file)->getSegment(*seg)->getStatus() == NZB_DL_SKIPPED) {
+			file_lock->unlock();
+			return false;
+		}
+		
 		if (nzblist->getFile(*file)->getSegment(*seg)->getStatus() == NZB_DECODING) {
 			file_lock->unlock();
 			return false;
@@ -280,7 +285,7 @@ void Output::writeOut(int file, int seg)
 		} else {
 			QStringList notok;
 			QString src;
-			notok << ".nzb" << ".sfv" << ".par" << ".par2" << ".nfo";
+			notok << ".nzb" << ".sfv" << ".par" << ".par2" << ".nfo" << ".jpg";
 			
 			src = nzblist->getFile(file)->getSegment(seg)->getFilename().mid(nzblist->getFile(file)->getSegment(seg)->getFilename().length() - 4, 4);
 			if (!notok.contains(src.toLower())) {
